gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: -annotate bugs


From: gnunet
Subject: [taler-exchange] branch master updated: -annotate bugs
Date: Tue, 05 Jul 2022 11:46:06 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new 75dbf20c -annotate bugs
75dbf20c is described below

commit 75dbf20cedb45d806a93b35124d10d9746527e88
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Tue Jul 5 11:46:02 2022 +0200

    -annotate bugs
---
 src/auditor/taler-helper-auditor-coins.c             | 2 +-
 src/auditor/taler-helper-auditor-reserves.c          | 4 ++--
 src/exchange/taler-exchange-httpd_batch-deposit.c    | 8 ++++----
 src/exchange/taler-exchange-httpd_csr.c              | 2 +-
 src/exchange/taler-exchange-httpd_db.c               | 4 ++--
 src/exchange/taler-exchange-httpd_deposit.c          | 4 ++--
 src/exchange/taler-exchange-httpd_extensions.c       | 2 +-
 src/exchange/taler-exchange-httpd_purses_merge.c     | 6 +++---
 src/exchange/taler-exchange-httpd_refreshes_reveal.c | 2 +-
 src/exchange/taler-exchange-router.c                 | 4 ++--
 src/exchangedb/plugin_exchangedb_postgres.c          | 2 +-
 src/lib/exchange_api_batch_deposit.c                 | 2 +-
 src/lib/exchange_api_common.c                        | 2 +-
 src/lib/exchange_api_recoup.c                        | 1 -
 src/lib/exchange_api_recoup_refresh.c                | 1 -
 src/lib/exchange_api_refund.c                        | 4 ++--
 src/testing/testing_api_cmd_batch_deposit.c          | 4 ++--
 src/testing/testing_api_cmd_deposit.c                | 4 ++--
 src/testing/testing_api_cmd_purse_deposit.c          | 2 +-
 src/util/crypto.c                                    | 2 +-
 src/util/crypto_helper_rsa.c                         | 2 +-
 src/util/taler-exchange-secmod-rsa.c                 | 2 +-
 22 files changed, 32 insertions(+), 34 deletions(-)

diff --git a/src/auditor/taler-helper-auditor-coins.c 
b/src/auditor/taler-helper-auditor-coins.c
index 20c9b2ed..e7fc81aa 100644
--- a/src/auditor/taler-helper-auditor-coins.c
+++ b/src/auditor/taler-helper-auditor-coins.c
@@ -1624,7 +1624,7 @@ deposit_cb (void *cls,
                                      &h_wire,
                                      &deposit->h_contract_terms,
                                      &deposit->coin.h_age_commitment,
-                                     NULL /* FIXME: h_extensions! */,
+                                     NULL /* FIXME-Oec: #7270: h_extensions! 
*/,
                                      &h_denom_pub,
                                      deposit->timestamp,
                                      &deposit->merchant_pub,
diff --git a/src/auditor/taler-helper-auditor-reserves.c 
b/src/auditor/taler-helper-auditor-reserves.c
index c6c4d3ad..547a4587 100644
--- a/src/auditor/taler-helper-auditor-reserves.c
+++ b/src/auditor/taler-helper-auditor-reserves.c
@@ -1819,8 +1819,8 @@ analyze_reserves (void *cls)
     GNUNET_break (GNUNET_DB_STATUS_SOFT_ERROR == qs);
     return qs;
   }
-#if FIXME
-  /* TODO: do we even care about these? */
+#if 0
+  /* FIXME #7269 (support for explicit reserve closure request) */
   qs = TALER_ARL_edb->select_close_requests_above_serial_id (
     TALER_ARL_edb->cls,
     ppr.last_close_requests_serial_id,
diff --git a/src/exchange/taler-exchange-httpd_batch-deposit.c 
b/src/exchange/taler-exchange-httpd_batch-deposit.c
index 154629ed..3e24f657 100644
--- a/src/exchange/taler-exchange-httpd_batch-deposit.c
+++ b/src/exchange/taler-exchange-httpd_batch-deposit.c
@@ -261,7 +261,7 @@ batch_deposit_transaction (void *cls,
                                  deposit,
                                  known_coin_id,
                                  &dc->h_payto,
-                                 false, /* FIXME-OEC: extension blocked */
+                                 false, /* FIXME-OEC: #7270 extension blocked 
*/
                                  &dc->exchange_timestamp,
                                  &balance_ok,
                                  &in_conflict);
@@ -279,7 +279,7 @@ batch_deposit_transaction (void *cls,
     }
     if (in_conflict)
     {
-      /* FIXME: conficting contract != insufficient funds */
+      /* FIXME: #7267 conficting contract != insufficient funds */
       *mhd_ret
         = TEH_RESPONSE_reply_coin_insufficient_funds (
             connection,
@@ -496,7 +496,7 @@ parse_coin (struct MHD_Connection *connection,
   deposit->h_contract_terms = dc->h_contract_terms;
   deposit->wire_salt = dc->wire_salt;
   deposit->receiver_wire_account = (char *) dc->payto_uri;
-  /* FIXME-OEC: should NOT insert the extension details N times,
+  /* FIXME-OEC: #7270 should NOT insert the extension details N times,
      but rather insert them ONCE and then per-coin only use
      the resulting extension UUID/serial; so the data structure
      here should be changed once we look at extensions in earnest.  */
@@ -606,7 +606,7 @@ TEH_handler_batch_deposit (struct TEH_RequestContext *rc,
   TALER_merchant_wire_signature_hash (dc.payto_uri,
                                       &dc.wire_salt,
                                       &dc.h_wire);
-  /* FIXME-OEC: hash actual extension JSON object here */
+  /* FIXME-OEC: #7270 hash actual extension JSON object here */
   // if (! no_extensions)
   memset (&dc.h_extensions,
           0,
diff --git a/src/exchange/taler-exchange-httpd_csr.c 
b/src/exchange/taler-exchange-httpd_csr.c
index 1abe5563..14d82ef1 100644
--- a/src/exchange/taler-exchange-httpd_csr.c
+++ b/src/exchange/taler-exchange-httpd_csr.c
@@ -178,7 +178,7 @@ TEH_handler_csr_melt (struct TEH_RequestContext *rc,
         }
 
         /* derive r_pub */
-        // FIXME: bundle all requests into one derivation request 
(TEH_keys_..., crypto helper, security module)
+        // FIXME-#7272: bundle all requests into one derivation request 
(TEH_keys_..., crypto helper, security module)
         ec = TEH_keys_denomination_cs_r_pub_melt (denom_pub_hash,
                                                   nonce,
                                                   r_pub);
diff --git a/src/exchange/taler-exchange-httpd_db.c 
b/src/exchange/taler-exchange-httpd_db.c
index 6f0fc41c..5660074e 100644
--- a/src/exchange/taler-exchange-httpd_db.c
+++ b/src/exchange/taler-exchange-httpd_db.c
@@ -61,7 +61,7 @@ TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
                                     NULL);
     return GNUNET_DB_STATUS_HARD_ERROR;
   case TALER_EXCHANGEDB_CKS_DENOM_CONFLICT:
-    /* FIXME: insufficient_funds != denom conflict! See issue 0007267, need new
+    /* FIXME: insufficient_funds != denom conflict! See issue #7267, need new
      * strategy for evidence gathering */
     *mhd_ret = TEH_RESPONSE_reply_coin_insufficient_funds (
       connection,
@@ -70,7 +70,7 @@ TEH_make_coin_known (const struct TALER_CoinPublicInfo *coin,
       &coin->coin_pub);
     return GNUNET_DB_STATUS_HARD_ERROR;
   case TALER_EXCHANGEDB_CKS_AGE_CONFLICT:
-    /* FIXME: insufficient_funds != Age conflict! See issue 0007267, need new
+    /* FIXME: insufficient_funds != Age conflict! See issue #7267, need new
      * strategy for evidence gathering */
     *mhd_ret = TEH_RESPONSE_reply_coin_insufficient_funds (
       connection,
diff --git a/src/exchange/taler-exchange-httpd_deposit.c 
b/src/exchange/taler-exchange-httpd_deposit.c
index 672e7b6e..b7466939 100644
--- a/src/exchange/taler-exchange-httpd_deposit.c
+++ b/src/exchange/taler-exchange-httpd_deposit.c
@@ -167,7 +167,7 @@ deposit_transaction (void *cls,
                                dc->deposit,
                                dc->known_coin_id,
                                &dc->h_payto,
-                               false, /* FIXME-OEC: extension blocked */
+                               false, /* FIXME-OEC: extension blocked #7270 */
                                &dc->exchange_timestamp,
                                &balance_ok,
                                &in_conflict);
@@ -184,7 +184,7 @@ deposit_transaction (void *cls,
   }
   if (in_conflict)
   {
-    /* FIXME: conficting contract != insufficient funds */
+    /* FIXME #7267: conficting contract != insufficient funds */
     *mhd_ret
       = TEH_RESPONSE_reply_coin_insufficient_funds (
           connection,
diff --git a/src/exchange/taler-exchange-httpd_extensions.c 
b/src/exchange/taler-exchange-httpd_extensions.c
index 5a613738..d6c26f6f 100644
--- a/src/exchange/taler-exchange-httpd_extensions.c
+++ b/src/exchange/taler-exchange-httpd_extensions.c
@@ -162,7 +162,7 @@ TEH_extensions_init ()
     return GNUNET_SYSERR;
   }
 
-  /* FIXME: shall we load the extensions from the config right away?
+  /* FIXME #7270: shall we load the extensions from the config right away?
    * We do have to for now, as otherwise denominations with age restriction
    * will not have the age mask set right upon initial generation.
    */
diff --git a/src/exchange/taler-exchange-httpd_refreshes_reveal.c 
b/src/exchange/taler-exchange-httpd_refreshes_reveal.c
index a0fd83bf..a25d6ff4 100644
--- a/src/exchange/taler-exchange-httpd_refreshes_reveal.c
+++ b/src/exchange/taler-exchange-httpd_refreshes_reveal.c
@@ -751,7 +751,7 @@ clean_age:
   {
     enum TALER_ErrorCode ec;
 
-    // FIXME: replace with a batch call that
+    // FIXME #7272: replace with a batch call that
     // passes all coins in once go!
     ec = TEH_keys_denomination_sign_melt (
       &rrcs[i].h_denom_pub,
diff --git a/src/exchange/taler-exchange-router.c 
b/src/exchange/taler-exchange-router.c
index 0816dfdb..a1a24719 100644
--- a/src/exchange/taler-exchange-router.c
+++ b/src/exchange/taler-exchange-router.c
@@ -32,7 +32,7 @@
 #include "taler_bank_service.h"
 
 
-// FIXME: revisit how (and if) we do sharding!
+// FIXME #7271: revisit how (and if) we do sharding!
 // Maybe use different helpers for wads than
 // for local purses?!
 /**
@@ -282,7 +282,7 @@ run_routing (void *cls)
   task = NULL;
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Checking for ready P2P transfers to route\n");
-  // FIXME: do actual work here!
+  // FIXME #7271: do actual work here!
   commit_or_warn ();
   release_shard (s);
   task = GNUNET_SCHEDULER_add_now (&run_shard,
diff --git a/src/exchangedb/plugin_exchangedb_postgres.c 
b/src/exchangedb/plugin_exchangedb_postgres.c
index cbacebbd..e5504e64 100644
--- a/src/exchangedb/plugin_exchangedb_postgres.c
+++ b/src/exchangedb/plugin_exchangedb_postgres.c
@@ -15553,7 +15553,7 @@ postgres_do_purse_deposit (
   bool *conflict)
 {
   struct PostgresClosure *pg = cls;
-  uint64_t partner_id = 0; /* FIXME: WAD support... */
+  uint64_t partner_id = 0; /* FIXME #7271: WAD support... */
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_uint64 (&partner_id),
     GNUNET_PQ_query_param_auto_from_type (purse_pub),
diff --git a/src/lib/exchange_api_batch_deposit.c 
b/src/lib/exchange_api_batch_deposit.c
index 043aa061..39c1c9b4 100644
--- a/src/lib/exchange_api_batch_deposit.c
+++ b/src/lib/exchange_api_batch_deposit.c
@@ -587,7 +587,7 @@ TALER_EXCHANGE_batch_deposit (
                                   deposits),
     GNUNET_JSON_pack_allow_null (
       GNUNET_JSON_pack_object_steal ("extension_details",
-                                     NULL)), /* FIXME-Oec */
+                                     NULL)), /* FIXME #7270-Oec */
     GNUNET_JSON_pack_timestamp ("timestamp",
                                 dcd->timestamp),
     GNUNET_JSON_pack_data_auto ("merchant_pub",
diff --git a/src/lib/exchange_api_common.c b/src/lib/exchange_api_common.c
index 739b215f..b64053f2 100644
--- a/src/lib/exchange_api_common.c
+++ b/src/lib/exchange_api_common.c
@@ -724,7 +724,7 @@ help_deposit (struct CoinHistoryParseContext *pc,
 {
   struct TALER_MerchantWireHashP h_wire;
   struct TALER_PrivateContractHashP h_contract_terms;
-  // struct TALER_ExtensionContractHashP h_extensions; // FIXME!
+  // struct TALER_ExtensionContractHashP h_extensions; // FIXME #7270!
   struct GNUNET_TIME_Timestamp wallet_timestamp;
   struct TALER_MerchantPublicKeyP merchant_pub;
   struct GNUNET_TIME_Timestamp refund_deadline = {0};
diff --git a/src/lib/exchange_api_recoup.c b/src/lib/exchange_api_recoup.c
index 49fb6fd5..8de4da12 100644
--- a/src/lib/exchange_api_recoup.c
+++ b/src/lib/exchange_api_recoup.c
@@ -296,7 +296,6 @@ TALER_EXCHANGE_recoup (struct TALER_EXCHANGE_Handle 
*exchange,
   {
     struct TALER_CsNonce nonce;
 
-    // FIXME: add this to the spec!
     /* NOTE: this is not elegant, and as per the note in TALER_coin_ev_hash()
        it is not strictly clear that the nonce is needed. Best case would be
        to find a way to include it more 'naturally' somehow, for example with
diff --git a/src/lib/exchange_api_recoup_refresh.c 
b/src/lib/exchange_api_recoup_refresh.c
index d551df74..00eeca07 100644
--- a/src/lib/exchange_api_recoup_refresh.c
+++ b/src/lib/exchange_api_recoup_refresh.c
@@ -309,7 +309,6 @@ TALER_EXCHANGE_recoup_refresh (
   {
     struct TALER_CsNonce nonce;
 
-    // FIXME: add this to the spec!
     /* NOTE: this is not elegant, and as per the note in TALER_coin_ev_hash()
        it is not strictly clear that the nonce is needed. Best case would be
        to find a way to include it more 'naturally' somehow, for example with
diff --git a/src/lib/exchange_api_refund.c b/src/lib/exchange_api_refund.c
index 2b0f5b03..a937c18a 100644
--- a/src/lib/exchange_api_refund.c
+++ b/src/lib/exchange_api_refund.c
@@ -236,7 +236,7 @@ verify_conflict_history_ok (struct 
TALER_EXCHANGE_RefundHandle *rh,
       struct TALER_PrivateContractHashP h_contract_terms;
       struct TALER_AgeCommitmentHash h_age_commitment;
       bool no_hac;
-      // struct TALER_ExtensionContractHashP h_extensions; // FIXME!
+      // struct TALER_ExtensionContractHashP h_extensions; // FIXME #7270!
       struct GNUNET_TIME_Timestamp wallet_timestamp;
       struct TALER_MerchantPublicKeyP merchant_pub;
       struct GNUNET_TIME_Timestamp refund_deadline;
@@ -280,7 +280,7 @@ verify_conflict_history_ok (struct 
TALER_EXCHANGE_RefundHandle *rh,
                                        no_hac
                                        ? NULL
                                        : &h_age_commitment,
-                                       NULL /* FIXME-OEC: h_extensions! */,
+                                       NULL /* FIXME #7270-OEC: h_extensions! 
*/,
                                        &h_denom_pub,
                                        wallet_timestamp,
                                        &merchant_pub,
diff --git a/src/testing/testing_api_cmd_batch_deposit.c 
b/src/testing/testing_api_cmd_batch_deposit.c
index 2ea03a51..967a5ac3 100644
--- a/src/testing/testing_api_cmd_batch_deposit.c
+++ b/src/testing/testing_api_cmd_batch_deposit.c
@@ -365,7 +365,7 @@ batch_deposit_run (void *cls,
                                &h_wire,
                                &h_contract_terms,
                                &cdd->h_age_commitment,
-                               NULL, /* FIXME: add hash of extensions */
+                               NULL, /* FIXME #7270: add hash of extensions */
                                &denom_pub->h_key,
                                ds->wallet_timestamp,
                                &merchant_pub,
@@ -381,7 +381,7 @@ batch_deposit_run (void *cls,
       .merchant_payto_uri = payto_uri,
       .wire_salt = wire_salt,
       .h_contract_terms = h_contract_terms,
-      .extension_details = NULL /* FIXME-OEC */,
+      .extension_details = NULL /* FIXME #7270-OEC */,
       .timestamp = ds->wallet_timestamp,
       .merchant_pub = merchant_pub,
       .refund_deadline = ds->refund_deadline
diff --git a/src/testing/testing_api_cmd_deposit.c 
b/src/testing/testing_api_cmd_deposit.c
index c54d8759..e48fec36 100644
--- a/src/testing/testing_api_cmd_deposit.c
+++ b/src/testing/testing_api_cmd_deposit.c
@@ -445,7 +445,7 @@ deposit_run (void *cls,
                                &h_wire,
                                &h_contract_terms,
                                &h_age_commitment,
-                               NULL, /* FIXME: add hash of extensions */
+                               NULL, /* FIXME #7270: add hash of extensions */
                                &denom_pub->h_key,
                                ds->wallet_timestamp,
                                &merchant_pub,
@@ -468,7 +468,7 @@ deposit_run (void *cls,
       .merchant_payto_uri = payto_uri,
       .wire_salt = wire_salt,
       .h_contract_terms = h_contract_terms,
-      .extension_details = NULL /* FIXME-OEC */,
+      .extension_details = NULL /* FIXME #7270-OEC */,
       .timestamp = ds->wallet_timestamp,
       .merchant_pub = merchant_pub,
       .refund_deadline = ds->refund_deadline
diff --git a/src/testing/testing_api_cmd_purse_deposit.c 
b/src/testing/testing_api_cmd_purse_deposit.c
index b10c6d32..b056497e 100644
--- a/src/testing/testing_api_cmd_purse_deposit.c
+++ b/src/testing/testing_api_cmd_purse_deposit.c
@@ -329,7 +329,7 @@ deposit_run (void *cls,
 
   ds->dh = TALER_EXCHANGE_purse_deposit (
     is->exchange,
-    NULL, /* FIXME: WADs support: purse exchange URL */
+    NULL, /* FIXME #7271: WADs support: purse exchange URL */
     &ds->purse_pub,
     ds->min_age,
     ds->num_coin_references,
diff --git a/src/util/crypto.c b/src/util/crypto.c
index 974566dc..5cbba813 100644
--- a/src/util/crypto.c
+++ b/src/util/crypto.c
@@ -244,7 +244,7 @@ TALER_cs_refresh_nonce_derive (
                                     sizeof (*nonce),
                                     &be_salt,
                                     sizeof (be_salt),
-                                    "refresh-n", // FIXME: value used in spec?
+                                    "refresh-n",
                                     strlen ("refresh-n"),
                                     rms,
                                     sizeof(*rms),
diff --git a/src/util/crypto_helper_rsa.c b/src/util/crypto_helper_rsa.c
index 9491b07c..92b79c95 100644
--- a/src/util/crypto_helper_rsa.c
+++ b/src/util/crypto_helper_rsa.c
@@ -602,7 +602,7 @@ TALER_CRYPTO_helper_rsa_batch_sign (
   struct TALER_BlindedDenominationSignature *bss)
 {
   GNUNET_break (0);
-  return -1; /* FIXME: NOT IMPLEMENTED! */
+  return -1; /* FIXME #7272: NOT IMPLEMENTED! */
 }
 
 
diff --git a/src/util/taler-exchange-secmod-rsa.c 
b/src/util/taler-exchange-secmod-rsa.c
index d4b0845f..efb7141c 100644
--- a/src/util/taler-exchange-secmod-rsa.c
+++ b/src/util/taler-exchange-secmod-rsa.c
@@ -1981,7 +1981,7 @@ run (void *cls,
   GNUNET_SCHEDULER_add_shutdown (&do_shutdown,
                                  NULL);
   if (0 == max_workers)
-    max_workers = 1; /* FIXME: or determine from CPU? */
+    max_workers = 1; /* FIXME-#7272: or determine from CPU? */
   for (unsigned int i = 0; i<max_workers; i++)
     if (GNUNET_OK !=
         start_worker ())

diff --git a/src/exchange/taler-exchange-httpd_purses_merge.c 
b/src/exchange/taler-exchange-httpd_purses_merge.c
index 144571d2..4fbdadb7 100644
--- a/src/exchange/taler-exchange-httpd_purses_merge.c
+++ b/src/exchange/taler-exchange-httpd_purses_merge.c
@@ -485,9 +485,9 @@ TEH_handler_purses_merge (
   }
   else
   {
-    char *method = GNUNET_strdup ("FIXME-WAD");
+    char *method = GNUNET_strdup ("FIXME-WAD #7271");
 
     /* FIXME: lookup wire method by pcc.provider_url! */
     pcc.wf = TEH_wire_fees_by_time (pcc.exchange_timestamp,
                                     method);
     if (NULL == pcc.wf)
@@ -553,7 +553,7 @@ TEH_handler_purses_merge (
 
   if (GNUNET_TIME_absolute_is_past (pcc.purse_expiration.abs_time))
   {
-    // FIXME: idempotency check, otherwise generate 410!
+    // FIXME-BUG: idempotency check, otherwise generate 410!
   }
 
   /* execute transaction */
@@ -485,9 +485,9 @@ TEH_handler_purses_merge (
 
-    /* FIXME: lookup wire method by pcc.provider_url! */
+    /* FIXME-#7271: lookup wire method by pcc.provider_url! */
     pcc.wf = TEH_wire_fees_by_time (pcc.exchange_timestamp,
                                     method);
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]